==> dojo-1.9.4.tgz: package/cldr/nls/ar/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"quarters-standAlone-narrow": [
		"١",
		"٢",
		"٣",
		"٤"
	],
	"field-weekday": "اليوم",
	"dateFormatItem-GyMMMEd": "E، d MMM، y G",
	"dateFormatItem-MMMEd": "E، d MMM",
	"eraNarrow": [
		"ص"
	],
	"days-format-short": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormat-long": "d MMMM، y G",
	"months-format-wide": [
		"تشري",
		"مرحشوان",
		"كيسلو",
		"طيفت",
		"شباط",
		"آذار الأول",
		"آذار",
		"نيسان",
		"أيار",
		"سيفان",
		"تموز",
		"آب",
		"أيلول"
	],
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dayPeriods-format-wide-pm": "م",
	"dateFormat-full": "EEEE، d MMMM، y G",
	"dateFormatItem-yyyyMEd": "E، d/M/y G",
	"dateFormatItem-Md": "d/M",
	"field-era": "العصر",
	"months-standAlone-wide": [
		"تشري",
		"مرحشوان",
		"كيسلو",
		"طيفت",
		"شباط",
		"آذار الأول",
		"آذار",
		"نيسان",
		"أيار",
		"سيفان",
		"تموز",
		"آب",
		"أيلول"
	],
	"timeFormat-short": "h:mm a",
	"quarters-format-wide": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"timeFormat-long": "h:mm:ss a z",
	"field-year": "السنة",
	"field-hour": "الساعات",
	"months-format-abbr": [
		"تشري",
		"مرحشوان",
		"كيسلو",
		"طيفت",
		"شباط",
		"آذار الأول",
		"آذار",
		"نيسان",
		"أيار",
		"سيفان",
		"تموز",
		"آب",
		"أيلول"
	],
	"timeFormat-full": "h:mm:ss a zzzz",
	"field-day-relative+0": "اليوم",
	"field-day-relative+1": "غدًا",
	"dateFormatItem-GyMMMd": "d MMM، y G",
	"field-day-relative+2": "بعد الغد",
	"months-standAlone-abbr": [
		"تشري",
		"مرحشوان",
		"كيسلو",
		"طيفت",
		"شباط",
		"آذار الأول",
		"آذار",
		"نيسان",
		"أيار",
		"سيفان",
		"تموز",
		"آب",
		"أيلول"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E، d MMM، y G",
	"days-standAlone-wide": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d MMM، y G",
	"timeFormat-medium": "h:mm:ss a",
	"eraAbbr": [
		"ص"
	],
	"field-minute": "الدقائق",
	"field-dayperiod": "ص/م",
	"days-standAlone-abbr": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"quarters-format-narrow": [
		"١",
		"٢",
		"٣",
		"٤"
	],
	"field-day-relative+-1": "أمس",
	"field-day-relative+-2": "أول أمس",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E، d/M",
	"field-day": "يوم",
	"days-format-wide": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"field-zone": "التوقيت",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "السنة الماضية",
	"field-month-relative+-1": "الشهر الماضي",
	"days-format-abbr": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"eraNames": [
		"ص"
	],
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-month": "الشهر",
	"days-standAlone-narrow": [
		"ح",
		"ن",
		"ث",
		"ر",
		"خ",
		"ج",
		"س"
	],
	"dayPeriods-format-wide-am": "ص",
	"dateFormat-short": "d/M/y GGGGG",
	"field-second": "الثواني",
	"field-month-relative+0": "هذا الشهر",
	"field-month-relative+1": "الشهر التالي",
	"dateFormatItem-Ed": "E، d",
	"field-week": "الأسبوع",
	"dateFormat-medium": "dd/MM/y G",
	"field-year-relative+0": "هذه السنة",
	"field-week-relative+-1": "الأسبوع الماضي",
	"dateFormatItem-yyyyM": "M/y G",
	"field-year-relative+1": "السنة التالية",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"months-format-wide-leap": "آذار الثاني",
	"dateFormatItem-GyMMM": "MMM y G",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "هذا الأسبوع",
	"field-week-relative+1": "الأسبوع التالي"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/ar/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"field-second-relative+0": "الآن",
	"quarters-standAlone-narrow": [
		"١",
		"٢",
		"٣",
		"٤"
	],
	"field-weekday": "اليوم",
	"field-wed-relative+0": "الأربعاء الحالي",
	"field-wed-relative+1": "الأربعاء التالي",
	"dateFormatItem-GyMMMEd": "E، d MMM، y G",
	"dateFormatItem-MMMEd": "E، d MMM",
	"eraNarrow": [
		"ص"
	],
	"field-tue-relative+-1": "الثلاثاء الماضي",
	"days-format-short": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormat-long": "d MMMM، y G",
	"field-fri-relative+-1": "الجمعة الماضية",
	"field-wed-relative+-1": "الأربعاء الماضي",
	"months-format-wide": [
		"تشري",
		"مرحشوان",
		"كيسلو",
		"طيفت",
		"شباط",
		"آذار الأول",
		"آذار",
		"نيسان",
		"أيار",
		"سيفان",
		"تموز",
		"آب",
		"أيلول"
	],
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dayPeriods-format-wide-pm": "م",
	"dateFormat-full": "EEEE، d MMMM، y G",
	"dateFormatItem-yyyyMEd": "E، d/M/y G",
	"field-thu-relative+-1": "الخميس الماضي",
	"dateFormatItem-Md": "d/M",
	"field-era": "العصر",
	"months-standAlone-wide": [
		"تشري",
		"مرحشوان",
		"كيسلو",
		"طيفت",
		"شباط",
		"آذار الأول",
		"آذار",
		"نيسان",
		"أيار",
		"سيفان",
		"تموز",
		"آب",
		"أيلول"
	],
	"timeFormat-short": "h:mm a",
	"quarters-format-wide": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"timeFormat-long": "h:mm:ss a z",
	"field-year": "السنة",
	"field-hour": "الساعات",
	"months-format-abbr": [
		"تشري",
		"مرحشوان",
		"كيسلو",
		"طيفت",
		"شباط",
		"آذار الأول",
		"آذار",
		"نيسان",
		"أيار",
		"سيفان",
		"تموز",
		"آب",
		"أيلول"
	],
	"field-sat-relative+0": "السبت الحالي",
	"field-sat-relative+1": "السبت التالي",
	"timeFormat-full": "h:mm:ss a zzzz",
	"field-day-relative+0": "اليوم",
	"field-thu-relative+0": "الخميس الحالي",
	"field-day-relative+1": "غدًا",
	"field-thu-relative+1": "الخميس التالي",
	"dateFormatItem-GyMMMd": "d MMM، y G",
	"field-day-relative+2": "بعد الغد",
	"months-standAlone-abbr": [
		"تشري",
		"مرحشوان",
		"كيسلو",
		"طيفت",
		"شباط",
		"آذار الأول",
		"آذار",
		"نيسان",
		"أيار",
		"سيفان",
		"تموز",
		"آب",
		"أيلول"
	],
	"quarters-format-abbr": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"quarters-standAlone-wide": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E، d MMM، y G",
	"days-standAlone-wide": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormatItem-yyyyMMM": "MMM، y G",
	"dateFormatItem-yyyyMMMd": "d MMM، y G",
	"timeFormat-medium": "h:mm:ss a",
	"field-sun-relative+0": "الأحد الحالي",
	"field-sun-relative+1": "الأحد التالي",
	"quarters-standAlone-abbr": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"eraAbbr": [
		"ص"
	],
	"field-minute": "الدقائق",
	"field-dayperiod": "ص/م",
	"days-standAlone-abbr": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"quarters-format-narrow": [
		"١",
		"٢",
		"٣",
		"٤"
	],
	"field-day-relative+-1": "أمس",
	"field-day-relative+-2": "أول أمس",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E، d/M",
	"field-fri-relative+0": "الجمعة الحالية",
	"field-fri-relative+1": "الجمعة التالية",
	"field-day": "يوم",
	"days-format-wide": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"field-zone": "التوقيت",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "السنة الماضية",
	"field-month-relative+-1": "الشهر الماضي",
	"days-format-abbr": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"eraNames": [
		"ص"
	],
	"days-format-narrow": [
		"ح",
		"ن",
		"ث",
		"ر",
		"خ",
		"ج",
		"س"
	],
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-month": "الشهر",
	"days-standAlone-narrow": [
		"ح",
		"ن",
		"ث",
		"ر",
		"خ",
		"ج",
		"س"
	],
	"field-tue-relative+0": "الثلاثاء الحالي",
	"field-tue-relative+1": "الثلاثاء التالي",
	"dayPeriods-format-wide-am": "ص",
	"field-mon-relative+0": "الاثنين الحالي",
	"field-mon-relative+1": "الاثنين التالي",
	"dateFormat-short": "d‏/M‏/y GGGGG",
	"field-second": "الثواني",
	"field-sat-relative+-1": "السبت الماضي",
	"field-sun-relative+-1": "الأحد الماضي",
	"field-month-relative+0": "هذا الشهر",
	"field-month-relative+1": "الشهر التالي",
	"dateFormatItem-Ed": "E، d",
	"field-week": "الأسبوع",
	"dateFormat-medium": "dd‏/MM‏/y G",
	"field-year-relative+0": "السنة الحالية",
	"field-week-relative+-1": "الأسبوع الماضي",
	"dateFormatItem-yyyyM": "M/y G",
	"field-year-relative+1": "السنة التالية",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"months-format-wide-leap": "آذار الثاني",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "الاثنين الماضي",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "هذا الأسبوع",
	"field-week-relative+1": "الأسبوع التالي"
}
//end v1.x content
);
